Learn R Programming

plasma (version 1.1.4)

TCGA-ESCA: Esophageal carcinoma (ESCA) data or lung squamous cell carcinoma (LUSC) data from The Cancer Genome Atlas (TCGA).

Description

The TCGA-ESCA dataset contains the objects assemble, Outcome, and m450info for building the MultiOmics object. Because its size exceeds the CRAN limits, the data is stored on a remote server and must be loaded using the function loadESCAdata.

The TCGA-LUSC1dataset is a parallel object for lung squamous cell carcinoma (LUSC) data, whihc must be loaded using the loadLUSCdata function.

Usage

loadESCAdata(env = plasmaEnv)
loadLUSCdata(env = plasmaEnv)

Arguments

env

an environment in which to load the data. The default value is a private environment in the package, accessible as plasmaEnv. To make access easier, you can use globalenv() or .GlobalEnv.

Format

The “TCGA-ESCA” dataset contains the following:

assemble

A list of 7 different omics dataframes with varying numbers of features as rows (D) and varying number of patients as columns (N). Note that some of these omics dataframes had been manipulated to contain NAs, where these may be complete on the GDC Dat Portal from which these data originally came. This was done to illustrate the capability of the plasma package on working with missing data.

Outcome

a dataframe (185x5) containing the survival outcomes for the patients in assemble.

m450info

a dataframe (1454x3) containing gene symbol, chromosome number, and genomic coordinate IDs corresponding to the features (or “probes”) in Meth450.

Author

Kevin R. Coombes krc@silicovore.com, Kyoko Yamaguchi kyoko.yamaguchi@osumc.edu

Examples

Run this code
fls <- try(loadESCAdata())
if (inherits(fls, "try-error")) {
  stop("Unable to load data from remote server.")
}

Run the code above in your browser using DataLab