The TCGA-ESCA dataset contains the objects assemble,
Outcome, and m450info for building the MultiOmics
object. Because its size exceeds the CRAN limits, the data is stored on
a remote server and must be loaded using the function
loadESCAdata.
The TCGA-LUSC1dataset is a parallel object for lung
squamous cell carcinoma (LUSC) data, whihc must be loaded using the
loadLUSCdata function.
loadESCAdata(env = plasmaEnv)
loadLUSCdata(env = plasmaEnv)
an environment in which to load the data. The default
value is a private environment in the package, accessible as
plasmaEnv. To make access easier, you can use
globalenv() or .GlobalEnv.
The “TCGA-ESCA” dataset contains the following:
assembleA list of 7 different omics dataframes with
varying numbers of features as rows (D) and varying number of
patients as columns (N). Note that some of these omics dataframes
had been manipulated to contain NAs, where these may be complete
on the GDC Dat Portal from which these data originally came. This
was done to illustrate the capability of the plasma package
on working with missing data.
Outcomea dataframe (185x5) containing the survival
outcomes for the patients in assemble.
m450infoa dataframe (1454x3) containing gene symbol,
chromosome number, and genomic coordinate IDs corresponding to the
features (or “probes”) in Meth450.
Kevin R. Coombes krc@silicovore.com, Kyoko Yamaguchi kyoko.yamaguchi@osumc.edu
fls <- try(loadESCAdata())
if (inherits(fls, "try-error")) {
stop("Unable to load data from remote server.")
}
Run the code above in your browser using DataLab